@@ -27,7 +27,7 @@ cp /etc/resolv.conf "${prefix}/etc/"
 #  2.  Setup yum.conf
 #
 arch=i386
-if [ $ARCH == "amd64" ] ; then
+if [ $ARCH = "amd64" ] ; then
     arch=x86_64
 fi
 
