@@ -48,7 +48,7 @@ done
 #  3.  Ensure that Yum has a working configuration file.
 #
 arch=i386
-if [ $ARCH == "amd64" ] ; then
+if [ $ARCH = "amd64" ] ; then
     arch=x86_64
 fi
 
